==> jc-1.4.0.tar.gz: soot/jimple/toolkits/callgraph/Filter.h <==
// public class soot.jimple.toolkits.callgraph.Filter

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class aca1790a167ce631 soot_jimple_toolkits_callgraph_Filter

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_callgraph_Filter_H_
#define _JC_soot_jimple_toolkits_callgraph_Filter_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Iterator$object;
struct _jc_soot_jimple_toolkits_callgraph_Edge$object;
struct _jc_soot_jimple_toolkits_callgraph_EdgePredicate$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_callgraph_Filter$sub_refs	_jc_soot_jimple_toolkits_callgraph_Filter$sub_refs;
typedef struct _jc_soot_jimple_toolkits_callgraph_Filter$sub_nonrefs	_jc_soot_jimple_toolkits_callgraph_Filter$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_callgraph_Filter$refs	_jc_soot_jimple_toolkits_callgraph_Filter$refs;
typedef struct _jc_soot_jimple_toolkits_callgraph_Filter$nonrefs	_jc_soot_jimple_toolkits_callgraph_Filter$nonrefs;
typedef struct _jc_soot_jimple_toolkits_callgraph_Filter$object	_jc_soot_jimple_toolkits_callgraph_Filter$object;

typedef const struct _jc_soot_jimple_toolkits_callgraph_Filter$vmethods	_jc_soot_jimple_toolkits_callgraph_Filter$vmethods;
typedef const struct _jc_soot_jimple_toolkits_callgraph_Filter$vtable	_jc_soot_jimple_toolkits_callgraph_Filter$vtable;
typedef const struct _jc_soot_jimple_toolkits_callgraph_Filter$vtype	_jc_soot_jimple_toolkits_callgraph_Filter$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_callgraph_Filter$method$_init$7b42b1ebea2e88bc(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_Filter$object *, struct _jc_object *);

// Virtual methods
extern void _jc_soot_jimple_toolkits_callgraph_Filter$method$advance$3cb6335d931ec4c0(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_Filter$object *);
extern jboolean _jc_soot_jimple_toolkits_callgraph_Filter$method$hasNext$fb0bd5e38c59ddcd(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_Filter$object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_toolkits_callgraph_Filter$method$next$05874f79a1cf66ea(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_Filter$object *);
extern void _jc_soot_jimple_toolkits_callgraph_Filter$method$remove$fd50149979e1f350(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_Filter$object *);
extern struct _jc_object *_jc_soot_jimple_toolkits_callgraph_Filter$method$wrap$0d5127e4f14ef9f7(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_Filter$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_callgraph_Filter$method_info$advance$3cb6335d931ec4c0;
extern _jc_method _jc_soot_jimple_toolkits_callgraph_Filter$method_info$hasNext$fb0bd5e38c59ddcd;
extern _jc_method _jc_soot_jimple_toolkits_callgraph_Filter$method_info$next$05874f79a1cf66ea;
extern _jc_method _jc_soot_jimple_toolkits_callgraph_Filter$method_info$remove$fd50149979e1f350;
extern _jc_method _jc_soot_jimple_toolkits_callgraph_Filter$method_info$wrap$0d5127e4f14ef9f7;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_callgraph_Filter$vmethods {
	void	(*advance$3cb6335d931ec4c0)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_Filter$object *);
	jboolean	(*hasNext$fb0bd5e38c59ddcd)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_Filter$object *);
	struct _jc_java_lang_Object$object	*(*next$05874f79a1cf66ea)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_Filter$object *);
	void	(*remove$fd50149979e1f350)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_Filter$object *);
	struct _jc_object	*(*wrap$0d5127e4f14ef9f7)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_Filter$object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_jimple_toolkits_callgraph_Filter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_callgraph_Filter$vmethods	soot_jimple_toolkits_callgraph_Filter;
};

// Vtype
struct _jc_soot_jimple_toolkits_callgraph_Filter$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_callgraph_Filter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_callgraph_Filter$sub_refs {
	struct _jc_object	*source;
	struct _jc_object	*pred;
	struct _jc_soot_jimple_toolkits_callgraph_Edge$object	*next;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_callgraph_Filter$refs {
    _jc_soot_jimple_toolkits_callgraph_Filter$sub_refs	soot_jimple_toolkits_callgraph_Filter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_callgraph_Filter$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_callgraph_Filter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_callgraph_Filter$sub_nonrefs	soot_jimple_toolkits_callgraph_Filter;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_callgraph_Filter$object {
	_jc_soot_jimple_toolkits_callgraph_Filter$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_callgraph_Filter$vtype	*vtype;
	_jc_soot_jimple_toolkits_callgraph_Filter$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_callgraph_Filter$vtype _jc_soot_jimple_toolkits_callgraph_Filter$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_callgraph_Filter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_callgraph_Filter$class_object;

#endif	/* _JC_soot_jimple_toolkits_callgraph_Filter_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/callgraph/Filter.h <==
// public class soot.jimple.toolkits.callgraph.Filter

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class aca1790a167ce631 soot_jimple_toolkits_callgraph_Filter

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_callgraph_Filter_H_
#define _JC_soot_jimple_toolkits_callgraph_Filter_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Iterator$object;
struct _jc_soot_jimple_toolkits_callgraph_Edge$object;
struct _jc_soot_jimple_toolkits_callgraph_EdgePredicate$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_callgraph_Filter$sub_refs	_jc_soot_jimple_toolkits_callgraph_Filter$sub_refs;
typedef struct _jc_soot_jimple_toolkits_callgraph_Filter$sub_nonrefs	_jc_soot_jimple_toolkits_callgraph_Filter$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_callgraph_Filter$refs	_jc_soot_jimple_toolkits_callgraph_Filter$refs;
typedef struct _jc_soot_jimple_toolkits_callgraph_Filter$nonrefs	_jc_soot_jimple_toolkits_callgraph_Filter$nonrefs;
typedef struct _jc_soot_jimple_toolkits_callgraph_Filter$object	_jc_soot_jimple_toolkits_callgraph_Filter$object;

typedef const struct _jc_soot_jimple_toolkits_callgraph_Filter$vmethods	_jc_soot_jimple_toolkits_callgraph_Filter$vmethods;
typedef const struct _jc_soot_jimple_toolkits_callgraph_Filter$vtable	_jc_soot_jimple_toolkits_callgraph_Filter$vtable;
typedef const struct _jc_soot_jimple_toolkits_callgraph_Filter$vtype	_jc_soot_jimple_toolkits_callgraph_Filter$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_callgraph_Filter$method$_init$7b42b1ebea2e88bc(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_Filter$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_toolkits_callgraph_Filter$method$advance$3cb6335d931ec4c0(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_Filter$object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_jimple_toolkits_callgraph_Filter$method$hasNext$fb0bd5e38c59ddcd(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_Filter$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_toolkits_callgraph_Filter$method$next$05874f79a1cf66ea(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_Filter$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_toolkits_callgraph_Filter$method$remove$fd50149979e1f350(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_Filter$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_jimple_toolkits_callgraph_Filter$method$wrap$0d5127e4f14ef9f7(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_Filter$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_callgraph_Filter$method_info$advance$3cb6335d931ec4c0;
extern _jc_method _jc_soot_jimple_toolkits_callgraph_Filter$method_info$hasNext$fb0bd5e38c59ddcd;
extern _jc_method _jc_soot_jimple_toolkits_callgraph_Filter$method_info$next$05874f79a1cf66ea;
extern _jc_method _jc_soot_jimple_toolkits_callgraph_Filter$method_info$remove$fd50149979e1f350;
extern _jc_method _jc_soot_jimple_toolkits_callgraph_Filter$method_info$wrap$0d5127e4f14ef9f7;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_callgraph_Filter$vmethods {
	void	(*advance$3cb6335d931ec4c0)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_Filter$object *) _JC_JCNI_ATTR;
	jboolean	(*hasNext$fb0bd5e38c59ddcd)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_Filter$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*next$05874f79a1cf66ea)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_Filter$object *) _JC_JCNI_ATTR;
	void	(*remove$fd50149979e1f350)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_Filter$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*wrap$0d5127e4f14ef9f7)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_Filter$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_toolkits_callgraph_Filter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_callgraph_Filter$vmethods	soot_jimple_toolkits_callgraph_Filter;
};

// Vtype
struct _jc_soot_jimple_toolkits_callgraph_Filter$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_callgraph_Filter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_callgraph_Filter$sub_refs {
	struct _jc_object	*source;
	struct _jc_object	*pred;
	struct _jc_soot_jimple_toolkits_callgraph_Edge$object	*next;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_callgraph_Filter$refs {
    _jc_soot_jimple_toolkits_callgraph_Filter$sub_refs	soot_jimple_toolkits_callgraph_Filter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_callgraph_Filter$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_callgraph_Filter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_callgraph_Filter$sub_nonrefs	soot_jimple_toolkits_callgraph_Filter;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_callgraph_Filter$object {
	_jc_soot_jimple_toolkits_callgraph_Filter$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_callgraph_Filter$vtype	*vtype;
	_jc_soot_jimple_toolkits_callgraph_Filter$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_callgraph_Filter$vtype _jc_soot_jimple_toolkits_callgraph_Filter$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_callgraph_Filter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_callgraph_Filter$class_object;

#endif	/* _JC_soot_jimple_toolkits_callgraph_Filter_H_ */
